@@ -1508,14 +1508,12 @@ void PAS__STD_init_a_file(V F_fd, V F_pfspc){
     break;
     case 4:((UL *)Rv1)[21]=((UL *)Rv1)[21]|512;
     break;
-    case 5:((UL *)Rv1)[21]=((UL *)Rv1)[21]|2048;
+    case 5:((UL *)Rv1)[21]=((UL *)Rv1)[21]|2304;
     break;
-    case 6:((UL *)Rv1)[21]=((UL *)Rv1)[21]|6144;
+    case 6:((UL *)Rv1)[21]=((UL *)Rv1)[21]|6400;
     break;
     default:break;
   }
-  if (16&((UL *)Rv1)[21]&&(((UL *)Rv1)[21]&6144)!=0) ((UL *)Rv1)[21]=((UL *)Rv1)
-  [21]|256;
   if ((6144&((UL *)Rv1)[21])==0) {
     if (isatty(((SL *)Rv1)[14])!=0) {
       ((UL *)Rv1)[21]=((UL *)Rv1)[21]|1280;
@@ -1541,7 +1539,7 @@ void PAS__STD_init_a_file(V F_fd, V F_pfspc){
   ((SL *)Rv1)[20]=0;
   ((SL *)Rv1)[19]=0;
   ((SL *)Rv1)[18]=0;
-  if (!Rv0&&1&((UL *)Rv1)[21]) {
+  if (!(256&((UL *)Rv1)[21])&&1&((UL *)Rv1)[21]) {
     if (4&((UL *)Rv1)[21]) P_buffer_map(F_fd,0);
     else {
       if (8192&((UL *)Rv1)[21]) PAS__exe_proc(((V *)Rv1)[5],F_fd);
@@ -1861,24 +1859,28 @@ V PAS__FILE_SPC(V Ret, V F_fp){
 }
 
 
-/* Procedure/Function : " get_tty_name "  */
-void PAS__STD_PRC_00000001(SL F_lun, V F_sn){
+/* Procedure/Function : " check_descr "  */
+void PAS__STD_PRC_00000001(SL F_lun, UL F_fmd, V F_sn){
   /* Local variable stored in C variable */
-  V Rv0;
-  SL Rv1;
-  C Rv2;
+  SL Rv0;
+  V Rv1;
+  SL Rv2;
+  C Rv3;
 
   /* Code of procedure/function */
-  Rv0=_Ttyname(F_lun);
-  Rv1=0;
-  if (Rv0!=NULL) while (1){
-    Rv2=((C *)Rv0)[Rv1];
-    if (Rv2==0)  break;
-    Rv1=Rv1+1;
-    ((C *)F_sn)[Rv1+1]=Rv2;
-    if (Rv1>=((UB *)F_sn)[0])  break;
+  Rv0=PAS__STD_get_kind_of_file(F_lun);
+  Rv1=_Ttyname(F_lun);
+  if (Rv1!=NULL) {
+    Rv2=0;
+    while (1){
+      Rv3=((C *)Rv1)[Rv2];
+      if (Rv3==0)  break;
+      Rv2=Rv2+1;
+      ((C *)F_sn)[Rv2+1]=Rv3;
+      if (Rv2>=((UB *)F_sn)[0])  break;
+    }
+    ((UB *)F_sn)[1]=Rv2;
   }
-  ((UB *)F_sn)[1]=Rv1;
 }
 
 
@@ -1908,22 +1910,22 @@ void PAS__INIT(SL F_parc, V F_parv, V F_penv){
   Ri.sl[43]=1;
   Ri.sl[44]=256;
   Ri.ul[49]=67109009;
-  if (isatty(Ri.sl[42])!=0) PAS__STD_PRC_00000001(Ri.sl[42],Ra.s);
-  else PAS__STR_TO_STR(Ra.s,Rd.s+76);
+  PAS__STR_TO_STR(Ra.s,Rd.s+76);
+  PAS__STD_PRC_00000001(Ri.sl[42],O_RDONLY, Ra.s);
   PAS__STD_init_a_file(Ri.s+112,Ra.s);
   Ri.sl[64]=1;
   Ri.sl[65]=1;
   Ri.sl[66]=256;
   Ri.ul[71]=146;
-  if (isatty(Ri.sl[64])!=0) PAS__STD_PRC_00000001(Ri.sl[64],Ra.s);
-  else PAS__STR_TO_STR(Ra.s,Rd.s+87);
+  PAS__STR_TO_STR(Ra.s,Rd.s+87);
+  PAS__STD_PRC_00000001(Ri.sl[64],O_WRONLY, Ra.s);
   PAS__STD_init_a_file(Ri.s+200,Ra.s);
   Ri.sl[86]=2;
   Ri.sl[87]=1;
   Ri.sl[88]=256;
   Ri.ul[93]=146;
-  if (isatty(Ri.sl[86])!=0) PAS__STD_PRC_00000001(Ri.sl[86],Ra.s);
-  else PAS__STR_TO_STR(Ra.s,Rd.s+99);
+  PAS__STR_TO_STR(Ra.s,Rd.s+99);
+  PAS__STD_PRC_00000001(Ri.sl[86],O_WRONLY, Ra.s);
   PAS__STD_init_a_file(Ri.s+288,Ra.s);
   Ri.sl[18]=-1;
   Ri.sl[19]=1;
